# Widget
Widgets are main raygap components and they have a *Widget decorator* and a *Render interface* for their class. The decorator is a function called before the class (Better to say before class constructor) and it has a *Render* interface for implements some render methods such as *canRender*, *willRender*, *didRender* and *render*.

# What is @Widget
As i said *Widget* is a decorator function that called before class constructor. It has 3 options:

- **name** {String} (important) widget name
- **render** {Boolean} (optional) render widget after constructor
- **style** {String} (optional) css style as string for styling the widget

```
import { Widget } from '@rayconnect/widget/common';

@Widget({
    name: "WIDGET_NAME",
    render: false,
    style: "body { background: #000000; }"
})
class WIDGET {

}
```

For style your widget you can require style file like this:
```
@Widget({
    ...
    style: require('./style.scss').default
    ...
})
```

# What is Render
Render is a interface for class to implements some methods such as *canRender*, *willRender*, *didRender* and *render*.

- **canRender** {boolean | Promise\<boolean>} (optional) can call *willRender* , *didRender* and *render*; if result (return) was true, *render* methods will called else was false will not call other methods and if your class didn't have this method, other methods will call.
- **willRender** {void} (optional) this methods execute before *render*
- **didRender** {void} (optional) this methods execute after *render*
- **render** {HTMLElement} (important) create HTML documents with javascript and please **don't** use *innerHTML* for creating HTML docuemnts

```
import { Render } from '@rayconnect/widget/common';

@Widget({
    ...
})
class WIDGET implements Render {
    canRender(): boolean | Promise<boolean> {
        return true;
    }
}
```