/**
 * @description set position of iframe on browser. It can be top-left top-right bottom-left bottom-right
 */

import { getIframeById } from './iframe';

export interface Position {
    horizontal: 'left' | 'right' | 'center'
    vertical: 'top' | 'bottom' | 'center'
}

export interface Margin {
    top?: string
    left?: string
    right?: string
    bottom?: string
}

/**
 * set position of iframe on bowser
 * @param {Position} position horizontal and vertical position of widget on browser
 * @param {Margin} margin margin top, left, right, bottom
 */
export default function setViewPosition(position: Position, margin?: Margin): void {
    let iframe = getIframeById();
    if (iframe) {
        switch (position.horizontal) {
            case 'center':
                iframe.style.left = margin?.left || '50%';
                iframe.style.transform = 'translate(-50%, 0)';
                break;
            case 'left':
                iframe.style.left = margin?.left || '0px';
                break;
            case 'right':
                iframe.style.right = margin?.right || '0px';
                break;
        }

        switch (position.vertical) {
            case 'center':
                iframe.style.top = margin?.top || '50%';
                iframe.style.transform = 'translate(0, -50%)';
                break;
            case 'top':
                iframe.style.top = margin?.top || '0px';
                break;
            case 'bottom':
                iframe.style.bottom = margin?.bottom || '0px';
                break;
        }

        if (position.horizontal == 'center' && position.vertical == 'center')
            iframe.style.transform = 'translate(-50%, -50%)';
    }
}