/**
 * @description Get iframe and get sizes of iframe from developer and create a css for responsive view and append to head of website
 */

import { getIframeById } from './iframe';

interface Size {
    width: string,
    height: string
}

export interface Sizes {
    desktop: Size
    tablet: Size
    mobile: Size
}

/**
  * @description Set size if view
  * @param {Sizes} sizes width and height on mobile & tablet & desktop sizes
  * @example { desktop: { width: '300px' }, mobile: { width: '100vh' } }
  */
export default function setViewSize(sizes: Sizes): void {
    const iframe = getIframeById();
    if (iframe) {
        const id: string | null = iframe.getAttribute('id');
        const styles = `
        /*
         *  Created by @rayconnect/widget
         */
        @media only screen and (max-width: 600px) {
            iframe#${id} {
                width: ${sizes.mobile.width};
                height: ${sizes.mobile.height};
            }
        }

        @media only screen and (min-width: 600px) and (max-width: 992px) {
            iframe#${id} {
                width: ${sizes.tablet.width};
                height: ${sizes.tablet.height};
            }
        }

        @media only screen and (min-width: 993px) {
            iframe#${id} {
                width: ${sizes.desktop.width};
                height: ${sizes.desktop.height};
            }
        }
        `;

        const style = document.createElement('style');
        style.textContent = styles;
        document.head.appendChild(style);
    }
}