import Render from '../common/render'; // Widget render interface

/**
 * @description Use widget first call canRender method then call willRender method then call render method and pass to callback and in the end call didRender method
 * @param {Render} widget A class with implemented render interface
 * @param {null|Function} callback What to do with rendered HTML document
 */
export default async function UseWidget(widget: Render, callback: null | Function): Promise<void> {
    // if canRender method was exists and result was true means can render or wasn't any canRender method means can render
    if ((widget.canRender != undefined && await widget.canRender() == true) || widget.canRender == undefined) {
        if (widget.willRender) await widget.willRender(); // will render method before render
        const render = widget.render(); // render HTML documents
        if (callback) callback(render); // if was any callback pass to it
        if (widget.didRender) await widget.didRender(); // do stuff after render
    }
}