import {
    AddStyle,
    Iframe,
    setIframe,
    getIframeById,
    setViewSize,
    Sizes,
    setViewPosition,
    Position,
    Margin,
    UseWidget,
} from '../core';

export class View {
    /**
     * @description Made a iframe for your widget
     * @param {string} id Your view id
     */
    constructor(id: string) {
        const iframe: HTMLIFrameElement = document.createElement('iframe');
        iframe.id = id;
        iframe.style.border = 'none';
        iframe.style.position = 'fixed';
        iframe.setAttribute('allowtransparency', 'true');
        setIframe(id);
        document.body.appendChild(iframe);
        this.styleIframe();
    }

    private styleIframe() {
        let ifram = Iframe();
        if (ifram) {
            const style = document.createElement('style');
            style.textContent = `
                /**
                 * Created by @rayconnect/widget
                 */
                 html, body {
                     background-color: transparent;
                     margin: 0;
                     overflow: hidden;
                 }
            `;
            ifram.head.appendChild(style);
        }
    }

    /**
     * @description clear your view and set a new body with a widget
     * @param {class} widget Your view body must be contain a widget
     */
    setBody(widget: any): void {
        UseWidget(new widget(), (render: HTMLElement) => {
            let iframe = Iframe();
            if (iframe) {
                iframe.body.innerHTML = '';
                iframe.body.appendChild(render);
            }
        });
    }

    /**
     * @description clear your view and load body from a url
     * @param {string} url Your widget url
     */
    loadBodyFromURL(url: string) {
        let iframe = Iframe();
        if (iframe) {
            iframe.body.innerHTML = '';
            getIframeById()?.setAttribute('src', url);
        }
    }

    /**
     * @description Add your string css style to head of view
     * @param {string} style  Your string css style
     */
    addStyle(style: string): void {
        AddStyle(style);
    }

    /**
     * @description Add a css style from a .css file link to head of view
     * @param {string} href Your css style from a .css link
     */
    addStyleLink(href: string): void {
        const link = document.createElement('link');
        link.href = href;
        link.rel = 'stylesheet';
        Iframe()?.head.appendChild(link);
    }

    /**
     * @description Add javascript string codes to head or body of view
     * @param {string} content Your javascript codes as a string
     * @param {head|body} on Head is your head of view and Body is your body of view
     */
    addScript(content: string, on: 'head' | 'body'): void {
        const script = document.createElement('script');
        script.textContent = content;
        if (on == 'body') Iframe()?.body.appendChild(script);
        else if (on == 'head') Iframe()?.head.appendChild(script);
        else;
    }

    /**
     * @description Add javascript codes from a .js link file to head or body of view
     * @param {string} src Your javascript codes as a .js link file
     * @param {head|body} on Head is your head of view and Body is your body of view
     */
    addScriptLink(src: string, on: 'head' | 'body'): void {
        const script = document.createElement('script');
        script.src = src;
        if (on == 'body') Iframe()?.body.appendChild(script);
        else if (on == 'head') Iframe()?.head.appendChild(script);
        else;
    }

    /**
     * @description Set size if view
     * @param {Sizes} sizes width and height on mobile & tablet & desktop sizes
     * @example { desktop: { width: '300px' }, mobile: { width: '100vh' } }
     */
    setSize(sizes: Sizes): void {
        setViewSize(sizes);
    }

    /**
     * set position of iframe on bowser
     * @param {Position} position horizontal and vertical position of widget on browser
     * @param {Margin} margin margin top, left, right, bottom
     */
    setPosition(position: Position, margin?: Margin): void {
        setViewPosition(position, margin);
    }
}